@@ -7,33 +7,6 @@
 #include "options_video.h"
 #include "main.h"
 
-static Evas_Object *op_trans, *op_opacity, *op_vidmod;
-
-static void
-_cb_op_video_trans_chg(void *data,
-                       Evas_Object *obj,
-                       void *_event EINA_UNUSED)
-{
-   Evas_Object *term = data;
-   Config *config = termio_config_get(term);
-   config->translucent = elm_check_state_get(obj);
-   elm_object_disabled_set(op_opacity, !config->translucent);
-   main_trans_update(config);
-   config_save(config, NULL);
-}
-
-static void
-_cb_op_video_opacity_chg(void *data,
-                         Evas_Object *obj,
-                         void *_event EINA_UNUSED)
-{
-   Evas_Object *term = data;
-   Config *config = termio_config_get(term);
-   config->opacity = elm_slider_value_get(obj);
-   if (!config->translucent) return;
-   main_trans_update(config);
-   config_save(config, NULL);
-}
 
 static void
 _cb_op_video_mute_chg(void *data,
@@ -76,7 +49,7 @@ _cb_op_video_vidmod_chg(void *data,
 void
 options_video(Evas_Object *opbox, Evas_Object *term)
 {
-   Evas_Object *o, *fr, *bx0;
+   Evas_Object *o, *fr, *bx0, *op_vidmod;
    Config *config = termio_config_get(term);
 
    fr = o = elm_frame_add(opbox);
@@ -85,44 +58,14 @@ options_video(Evas_Object *opbox, Evas_Object *term)
    elm_object_text_set(o, _("Video"));
    elm_box_pack_end(opbox, o);
    evas_object_show(o);
-   
+
    bx0 = o = elm_box_add(opbox);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
    elm_object_content_set(fr, o);
    evas_object_show(o);
-   
-   op_trans = o = elm_check_add(opbox);
-   evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
-   evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
-   elm_object_text_set(o, _("Translucent"));
-   elm_check_state_set(o, config->translucent);
-   elm_box_pack_end(bx0, o);
-   evas_object_show(o);
-   evas_object_smart_callback_add(o, "changed",
-                                  _cb_op_video_trans_chg, term);
 
-   op_opacity = o = elm_slider_add(opbox);
-   evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
-   evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
-   elm_slider_span_size_set(o, 40);
-   elm_slider_unit_format_set(o, _("%1.0f%%"));
-   elm_slider_indicator_format_set(o, _("%1.0f%%"));
-   elm_slider_min_max_set(o, 0, 100);
-   elm_slider_value_set(o, config->opacity);
-   elm_object_disabled_set(o, !config->translucent);
-   elm_box_pack_end(bx0, o);
-   evas_object_show(o);
-   evas_object_smart_callback_add(o, "changed",
-                                  _cb_op_video_opacity_chg, term);
 
-   o = elm_separator_add(opbox);
-   evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
-   evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
-   elm_separator_horizontal_set(o, EINA_TRUE);
-   elm_box_pack_end(bx0, o);
-   evas_object_show(o);
-   
    o = elm_check_add(opbox);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
@@ -152,7 +95,7 @@ options_video(Evas_Object *opbox, Evas_Object *term)
    elm_separator_horizontal_set(o, EINA_TRUE);
    elm_box_pack_end(bx0, o);
    evas_object_show(o);
-   
+
    o = elm_label_add(opbox);
    evas_object_size_hint_weight_set(o, 0.0, 0.0);
    evas_object_size_hint_align_set(o, 0.0, 0.5);
@@ -169,7 +112,7 @@ options_video(Evas_Object *opbox, Evas_Object *term)
    evas_object_show(o);
    evas_object_smart_callback_add(o, "changed",
                                   _cb_op_video_vidmod_chg, term);
-   
+
    o = elm_radio_add(opbox);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
@@ -180,7 +123,7 @@ options_video(Evas_Object *opbox, Evas_Object *term)
    evas_object_show(o);
    evas_object_smart_callback_add(o, "changed",
                                   _cb_op_video_vidmod_chg, term);
-   
+
    o = elm_radio_add(opbox);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
@@ -191,7 +134,7 @@ options_video(Evas_Object *opbox, Evas_Object *term)
    evas_object_show(o);
    evas_object_smart_callback_add(o, "changed",
                                   _cb_op_video_vidmod_chg, term);
-   
+
    o = elm_radio_add(opbox);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, 0.5);
@@ -213,7 +156,7 @@ options_video(Evas_Object *opbox, Evas_Object *term)
    evas_object_show(o);
    evas_object_smart_callback_add(o, "changed",
                                   _cb_op_video_vidmod_chg, term);
-   
+
    elm_radio_value_set(o, config->vidmod);
 
    evas_object_size_hint_weight_set(opbox, EVAS_HINT_EXPAND, 0.0);
