@@ -3,6 +3,6 @@
 
 #include "termpty.h"
 
-Eina_Unicode _termpty_charset_trans(Eina_Unicode g, Termpty *ty);
+Eina_Unicode _termpty_charset_trans(const Termpty *ty, Eina_Unicode g);
 
 #endif
